@@ -7,9 +7,9 @@ import pyqtgraph as pg
 from .receiver import QThreadReceiver
 
 
-class ImagePlotter():
+class ImagePlotter:
     DEFAULT_SIZE = (600, 400)
-    DEFAULT_TITLE = 'Image Plotter'
+    DEFAULT_TITLE = "Image Plotter"
 
     def __init__(self, addr: str, port: int):
         self.app = QApplication([])
@@ -18,7 +18,7 @@ class ImagePlotter():
         self.win.show()
 
         self.imageitem = pg.ImageItem()
-        self.imageitem.setOpts(axisOrder='row-major')
+        self.imageitem.setOpts(axisOrder="row-major")
 
         self.viewbox = self.win.addViewBox()
         self.viewbox.setAspectLocked(lock=True)
@@ -43,24 +43,26 @@ class ImagePlotter():
         self.receiver.start()
 
     def set_attributes(self, attrs: dict):
-        if 'xlabel' in attrs:
-            self.plotitem.setLabel('bottom', attrs['xlabel'])
-        if 'ylabel' in attrs:
-            self.plotitem.setLabel('left', attrs['ylabel'])
-        if 'windowsize' in attrs:
-            self.win.resize(*attrs['windowsize'])
+        if "xlabel" in attrs:
+            self.plotitem.setLabel("bottom", attrs["xlabel"])
+        if "ylabel" in attrs:
+            self.plotitem.setLabel("left", attrs["ylabel"])
+        if "windowsize" in attrs:
+            self.win.resize(*attrs["windowsize"])
 
     def clear(self):
         self.imageitem.clear()
 
     def draw(self, img):
-        """
-        args:
-            - img, 2d array_like
+        """Draw the image.
+
+        If ``img`` is not 2-dimensional, do nothing.
+
+        Args:
+            img (2d array_like): an image to be drawn.
         """
         vec = np.array(img)
         if len(vec.shape) != 2:
-            self.clear()
             return
 
         self.imageitem.setImage(vec)
